[Rivet-svn] r4221 - branches/2012-06-aidarivet/src/Analyses

blackhole at projects.hepforge.org blackhole at projects.hepforge.org
Sun Mar 10 17:24:45 GMT 2013


Author: buckley
Date: Sun Mar 10 17:24:45 2013
New Revision: 4221

Log:
Properly fix the src/Analyses/ATLAS_2012_I1119557.cc problem by also adding the function *declarations* into the unnamed namespace.

Modified:
   branches/2012-06-aidarivet/src/Analyses/ATLAS_2012_I1119557.cc

Modified: branches/2012-06-aidarivet/src/Analyses/ATLAS_2012_I1119557.cc
==============================================================================
--- branches/2012-06-aidarivet/src/Analyses/ATLAS_2012_I1119557.cc	Sun Mar 10 17:24:04 2013	(r4220)
+++ branches/2012-06-aidarivet/src/Analyses/ATLAS_2012_I1119557.cc	Sun Mar 10 17:24:45 2013	(r4221)
@@ -8,12 +8,13 @@
 namespace Rivet {
 
 
-  // Forward declarations of calculator functions: implementations at bottom of file
-  double getWidth(const Jet& jet);
-  double getEcc(const Jet& jet);
-  double getPFlow(const Jet& jet);
-  double getAngularity(const Jet& jet);
-
+  namespace { // unnamed namespace
+    // Forward declarations of calculator functions: implementations at bottom of file
+    double getWidth(const Jet& jet);
+    double getEcc(const Jet& jet);
+    double getPFlow(const Jet& jet);
+    double getAngularity(const Jet& jet);
+  }
 
 
   class ATLAS_2012_I1119557 : public Analysis {


More information about the Rivet-svn mailing list